package com.reviewanalysisweb.dao;

import com.mongodb.BasicDBObject;
import com.mongodb.BasicDBObjectBuilder;
import com.mongodb.DBCollection;
import com.mongodb.DBCursor;
import com.mongodb.DBObject;
import com.mongodb.MongoClient;
import com.reviewanalysisweb.converter.MetaConverter;
import com.reviewanalysisweb.converter.ReviewConverter;
import com.reviewanalysisweb.model.Meta;
import com.reviewanalysisweb.model.Review;
import java.util.ArrayList;
import java.util.List;
import org.bson.types.ObjectId;

/**
 *
 * @author monicaribeiro
 */
public class MongoDBMetaDAO 
{
    private DBCollection col;
    private DBCollection collection;
 
    public MongoDBMetaDAO(MongoClient mongo) 
    {
        this.col = mongo.getDB("reviewanalysis").getCollection("meta");
        this.collection = mongo.getDB("reviewanalysis").getCollection("reviews");
    }
 
    public void updateReview(Meta m) 
    {
        DBObject query = BasicDBObjectBuilder.start()
                .append("_id", new ObjectId(m.getId())).get();
        this.col.update(query, MetaConverter.toDBObject(m));
    }
    
    public List<Meta> readAllReview() 
    {
        List<Meta> data = new ArrayList<Meta>();
        DBCursor cursor = col.find();
        while (cursor.hasNext()) 
        {
            DBObject doc = cursor.next();
            Meta m = MetaConverter.toMeta(doc);
            data.add(m);
        }
        
        /*int contador = 10;
        while (contador >= 0)
        {
            DBObject doc = cursor.next();
            Meta m = MetaConverter.toMeta(doc);
            data.add(m);
            contador = contador - 1;
        }*/
        return data;
    }
    
    public List<Meta> readLimitedReviews() 
    {
        List<Meta> data = new ArrayList<Meta>();
        DBCursor cursor = col.find();
        
        int contador = 10;
        while (contador >= 0)
        {
            DBObject doc = cursor.next();
            Meta m = MetaConverter.toMeta(doc);
            data.add(m);
            contador = contador - 1;
        }
        return data;
    }
    
    public List<String> getReviewsId (String atribute, String parameterSelected)
    {
        List<String> reviewsId = new ArrayList<String>();
        DBCursor cursor = col.find(new BasicDBObject(atribute, parameterSelected));
        
        while (cursor.hasNext())
        {
            DBObject doc = cursor.next();
            Meta m = MetaConverter.toMeta(doc);
            DBCursor c = collection.find(new BasicDBObject("reviewId", m.getReviewId()));
            
            while(c.hasNext())
            {
                DBObject document = c.next();
                Review r = ReviewConverter.toReview(document);
                reviewsId.add(r.getReviewId());
            }
        }
        
        return reviewsId;
    }
    
    public List<Meta> readSpecificReview(String atribute, String parameterSelected)
    {
        List<Meta> dataMeta = new ArrayList<Meta>();
        DBCursor cursor = col.find(new BasicDBObject(atribute, parameterSelected));
        
        while (cursor.hasNext())
        {
            DBObject doc = cursor.next();
            Meta m = MetaConverter.toMeta(doc);
            dataMeta.add(m);
        }
        return dataMeta;
    }
    
    public List<Meta> readSpecificReviewUsingFilters(String userId, String appId, String date)
    {
        List<Meta> dataMeta = new ArrayList<Meta>();
        BasicDBObject query = new BasicDBObject();
        
        if(userId != "")
        {
            query.put("userId", userId);
        }
        
        if(appId != "")
        {
            query.put("appId", appId);
        }
        
        if(date != "")
        {
            query.put("date", date);
        }
        
        DBCursor cursor = col.find(query);
        
        while (cursor.hasNext())
        {
            DBObject doc = cursor.next();
            Meta m = MetaConverter.toMeta(doc);
            dataMeta.add(m);
        }
        
        return dataMeta;
    }
 
    public Meta readMeta (Meta m) 
    {
        DBObject query = BasicDBObjectBuilder.start()
                .append("_id", new ObjectId(m.getId())).get();
        DBObject data = this.col.findOne(query);
        return MetaConverter.toMeta(data);
    }
}
