package com.reviewanalysisweb.servlets;

import com.mongodb.MongoClient;
import com.reviewanalysisweb.dao.MongoDBReviewDAO;
import com.reviewanalysisweb.model.Review;
import java.io.IOException;
import java.util.List;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 *
 * @author monicaribeiro
 */

@WebServlet("/editReview")
public class EditReviewServlet extends HttpServlet 
{
    private static final long serialVersionUID = -6554920927964049383L;
 
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException 
    {
        String id = request.getParameter("id");
        if (id == null || "".equals(id)) 
        {
            throw new ServletException("id missing for edit operation");
        }
        
        System.out.println("Review edit requested with id=" + id);
        
        MongoClient mongo = (MongoClient) request.getServletContext().getAttribute("MONGO_CLIENT");
        MongoDBReviewDAO reviewDAO = new MongoDBReviewDAO(mongo);
        Review r = new Review();
        r.setId(id);
        r = reviewDAO.readReview(r);
        request.setAttribute("review", r);
        List<Review> reviews = reviewDAO.readAllReview();
        request.setAttribute("persons", reviews);
 
        RequestDispatcher rd = getServletContext().getRequestDispatcher("/reviews.jsp");
        rd.forward(request, response);
    }
 
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException 
    {
        String id = request.getParameter("id"); // keep it non-editable in UI
        if (id == null || "".equals(id)) 
        {
            throw new ServletException("id missing for edit operation");
        }
       
        String content = request.getParameter("content");
        String title = request.getParameter("title");
        String reviewId = request.getParameter("reviewId");
        String appId = request.getParameter("appId");
    
        if ((content == null || content.equals(""))
                || (title == null || title.equals(""))
                || (reviewId == null || reviewId.equals(""))
                || (appId == null || appId.equals(""))) 
        {
            request.setAttribute("error", "Content, Title, ReviewId, AppId can't be empty");
            MongoClient mongo = (MongoClient) request.getServletContext()
                    .getAttribute("MONGO_CLIENT");
            MongoDBReviewDAO reviewDAO = new MongoDBReviewDAO(mongo);
            Review r = new Review();
            r.setId(id);
            r.setAppId(appId);
            r.setContent(content);
            r.setReviewId(reviewId);
            r.setTitle(title);
            
            request.setAttribute("review", r);
            List<Review> reviews = reviewDAO.readAllReview();
            request.setAttribute("reviews", reviews);
 
            RequestDispatcher rd = getServletContext().getRequestDispatcher("/reviews.jsp");
            rd.forward(request, response);
        } else 
        {
            MongoClient mongo = (MongoClient) request.getServletContext()
                    .getAttribute("MONGO_CLIENT");
            MongoDBReviewDAO reviewDAO = new MongoDBReviewDAO(mongo);
            Review r = new Review();
            r.setId(id);
            r.setAppId(appId);
            r.setContent(content);
            r.setReviewId(reviewId);
            r.setTitle(title);
            reviewDAO.updateReview(r);
            System.out.println("Review edited successfully with id=" + id);
            request.setAttribute("success", "Review edited successfully");
            List<Review> reviews = reviewDAO.readAllReview();
            request.setAttribute("reviews", reviews);
 
            RequestDispatcher rd = getServletContext().getRequestDispatcher("/reviews.jsp");
            rd.forward(request, response);
        }
    }
 
}