package com.reviewanalysisweb.servlets;

import com.mongodb.MongoClient;
import com.reviewanalysisweb.dao.MongoDBMetaDAO;
import com.reviewanalysisweb.dao.MongoDBReviewDAO;
import com.reviewanalysisweb.model.Meta;
import com.reviewanalysisweb.model.Review;
import com.reviewanalysisweb.service.ReviewSearchService;
import java.io.IOException;
import java.util.List;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 *
 * @author monicaribeiro
 */

@WebServlet("/listOfReviews")
public class ListReviewsListServlet extends HttpServlet 
{
    private static final long serialVersionUID = -7060758261496829905L;
    
    private String atribute;
    
    protected void doPost(HttpServletRequest request,HttpServletResponse response) 
            throws ServletException, IOException {
        
        String userParameterSelected = request.getParameter("userRankingValue");
        String productParameterSelected = request.getParameter("productRankingValue");
        String reviewParameterSelected = request.getParameter("reviewRankingValue");
        
        Meta m = new Meta();
			
	MongoClient mongo = (MongoClient) request.getServletContext().getAttribute("MONGO_CLIENT");
	MongoDBMetaDAO metaDAO = new MongoDBMetaDAO(mongo);
        MongoDBReviewDAO reviewDAO = new MongoDBReviewDAO(mongo);
        
        if(userParameterSelected != null) 
        {
            atribute = "username";
            searchForReviews(metaDAO, userParameterSelected, reviewDAO, request, response, atribute);
        }
        
        if(productParameterSelected != null) 
        {
            atribute = "appId";
            searchForReviews(metaDAO, productParameterSelected, reviewDAO, request, response, atribute);
        }
        
        if(reviewParameterSelected != null) 
        {
            atribute = "reviewId";
            searchForReviews(metaDAO, reviewParameterSelected, reviewDAO, request, response, atribute);
        }
    }
    
    protected void searchForReviews(
            MongoDBMetaDAO metaDAO, 
            String parameterSelected, 
            MongoDBReviewDAO reviewDAO, 
            HttpServletRequest request,
            HttpServletResponse response, 
            String atribute) throws ServletException, IOException {
        
        List<Meta> metas = metaDAO.readSpecificReview(atribute, parameterSelected);
        List<String> reviewsId = metaDAO.getReviewsId(atribute, parameterSelected);
        List<Review> reviews = reviewDAO.readSpecificReview(reviewsId);
        
        //TODO to gbaierle: find a way to otimize and refactor this method
        metas = addReviewAttributesToMeta(metas, reviews);
        
        request.setAttribute("metas", metas);
        
        RequestDispatcher rd = getServletContext().getRequestDispatcher("/listOfReviews.jsp");
        rd.forward(request, response);
    
    }

    /**
     * 
     */
    private List<Meta> addReviewAttributesToMeta(List<Meta> metas, List<Review> reviews) {
        
        for (Review review : reviews) {
            
            for (Meta meta : metas) {
                
                if (review.getReviewId().equals(meta.getReviewId())) {
                    
                    meta.setTitle(review.getTitle());
                    meta.setContent(review.getContent());
                }
            }
        }
        
        return metas;
    }
        
}
